#ifndef __BASE_IO_H__
#define __BASE_IO_H__

#include <glib.h>

extern gchar      * data_dir;
extern gchar      * download_dir;
extern gint         acache_max_megs;
extern gboolean     acache_flush_on_exit;
extern gboolean     break_thread_when_subject_changes;

void base_prefs_init (const gchar * data_dir,
                      const gchar * download_dir,
                      gint          acache_max_megs,
                      gboolean      acache_flush_on_exit,
		      gboolean      break_thread_when_subject_changes);

#endif
